import { defineConfig, loadEnv, ConfigEnv, UserConfig } from 'vite'
import { createHtmlPlugin } from 'vite-plugin-html'
import vue from '@vitejs/plugin-vue'
import { resolve } from 'path'
// import eslintPlugin from "vite-plugin-eslint";
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers'

// https://vitejs.dev/config/
export default defineConfig(({ mode }: ConfigEnv): UserConfig => {
  const env = loadEnv(mode, process.cwd())

  return {
    resolve: {
      alias: {
        '~': resolve(__dirname, './'),
        '@': resolve(__dirname, './src')
      }
    },
    server: {
      open: true,
      host: '0.0.0.0',
      proxy: {
        '/api': {
          target: 'http://erp.baozhida.cn',
          changeOrigin: true,
          rewrite: path => path.replace(/^\/api/, '')
        },
        '/salary': {
          target: 'http://erp.baozhida.cn',
          changeOrigin: true
          // rewrite: path => path.replace(/^\/salary/, '')
        },
        '/ams': {
          target: 'http://erp.baozhida.cn',
          changeOrigin: true
          // rewrite: path => path.replace(/^\/ams/, '')
        }
      }
    },
    plugins: [
      vue(),
      createHtmlPlugin({
        inject: {
          data: {
            title: env.VITE_BZD_ERP_APP_TITLE
          }
        }
      }),
      // eslintPlugin({
      //   include: ["src/**/*.js", "src/**/*.vue", "src/*.js", "src/*.vue"],
      // }),
      AutoImport({
        resolvers: [ElementPlusResolver()]
      }),
      Components({
        resolvers: [ElementPlusResolver()]
      })
    ],
    // * 打包去除 console.log && debugger
    esbuild: {
      pure: env.VITE_DROP_CONSOLE ? ['console.log', 'debugger'] : []
    }
  }
})
